@@ -99,6 +99,8 @@ Utility functions and constants usable in various circumstances.
     Exports of :py:mod:`ocrd_utils.logging`
 
 * :py:func:`deprecated_alias`
+* :py:func:`rename_kwargs`
+* :py:func:`deprecation_warning`
 
     Decorator to mark a kwarg as deprecated
 """
@@ -118,7 +120,9 @@ from .constants import (
     )
 
 from .deprecate import (
-    deprecated_alias)
+    deprecated_alias,
+    rename_kwargs,
+    deprecation_warning)
 
 from .image import (
     adjust_canvas_to_rotation,
@@ -157,11 +161,11 @@ from .introspect import (
 )
 
 from .logging import (
+    tf_disable_interactive_logs,
     disableLogging,
     getLevelName,
     getLogger,
     initLogging,
-    logging,
     setOverrideLogLevel,
     )
 
@@ -171,12 +175,14 @@ from .os import (
     get_processor_resource_types,
     get_ocrd_tool_json,
     get_moduledir,
+    guess_media_type,
     list_all_resources,
     is_file_in_directory,
     list_resource_candidates,
     atomic_write,
     pushd_popd,
     unzip_file_to_dir,
+    redirect_stderr_and_stdout_to_file,
     )
 
 from .str import (
@@ -192,3 +198,5 @@ from .str import (
     parse_json_string_with_comments,
     remove_non_path_from_url,
     safe_filename)
+
+from .config import config
